# API Reference <a name="API Reference"></a>

## Constructs <a name="Constructs"></a>

### GrafanaHandler <a name="cdk-grafana-json-dashboard-handler.GrafanaHandler"></a>

#### Initializers <a name="cdk-grafana-json-dashboard-handler.GrafanaHandler.Initializer"></a>

```typescript
import { GrafanaHandler } from 'cdk-grafana-json-dashboard-handler'

new GrafanaHandler(scope: Construct, id: string, props: GrafanaHandlerProps)
```

##### `scope`<sup>Required</sup> <a name="cdk-grafana-json-dashboard-handler.GrafanaHandler.parameter.scope"></a>

- *Type:* [`@aws-cdk/core.Construct`](#@aws-cdk/core.Construct)

---

##### `id`<sup>Required</sup> <a name="cdk-grafana-json-dashboard-handler.GrafanaHandler.parameter.id"></a>

- *Type:* `string`

---

##### `props`<sup>Required</sup> <a name="cdk-grafana-json-dashboard-handler.GrafanaHandler.parameter.props"></a>

- *Type:* [`cdk-grafana-json-dashboard-handler.GrafanaHandlerProps`](#cdk-grafana-json-dashboard-handler.GrafanaHandlerProps)

---



#### Properties <a name="Properties"></a>

##### `grafanaFunctionCRHandler`<sup>Required</sup> <a name="cdk-grafana-json-dashboard-handler.GrafanaHandler.property.grafanaFunctionCRHandler"></a>

```typescript
public readonly grafanaFunctionCRHandler: CustomResource;
```

- *Type:* [`@aws-cdk/core.CustomResource`](#@aws-cdk/core.CustomResource)

---

##### `grafanaHandlerFunction`<sup>Required</sup> <a name="cdk-grafana-json-dashboard-handler.GrafanaHandler.property.grafanaHandlerFunction"></a>

```typescript
public readonly grafanaHandlerFunction: SingletonFunction;
```

- *Type:* [`@aws-cdk/aws-lambda.SingletonFunction`](#@aws-cdk/aws-lambda.SingletonFunction)

---


## Structs <a name="Structs"></a>

### GrafanaHandlerProps <a name="cdk-grafana-json-dashboard-handler.GrafanaHandlerProps"></a>

Properties for a newly created Grafana Handler Construct.

A valid Grafana dashboard JSON has an uid, id and title key in the root of the object. We generate these based on input so static JSON files are not a problem when wanting to deploy more dynamic but the end result is still deterministic. This is all derived from the dashboardAppName property

#### Initializer <a name="[object Object].Initializer"></a>

```typescript
import { GrafanaHandlerProps } from 'cdk-grafana-json-dashboard-handler'

const grafanaHandlerProps: GrafanaHandlerProps = { ... }
```

##### `bucketName`<sup>Required</sup> <a name="cdk-grafana-json-dashboard-handler.GrafanaHandlerProps.property.bucketName"></a>

```typescript
public readonly bucketName: string;
```

- *Type:* `string`

The name of the S3 bucket containing your dashboard file.

---

##### `dashboardAppName`<sup>Required</sup> <a name="cdk-grafana-json-dashboard-handler.GrafanaHandlerProps.property.dashboardAppName"></a>

```typescript
public readonly dashboardAppName: string;
```

- *Type:* `string`

A unique identifier to identify this dashboard in Grafana.

This identifier is used to set or overwrite the title, id and uid keys in the dashboard json file The identifier should be unique!

---

##### `grafanaPwSecret`<sup>Required</sup> <a name="cdk-grafana-json-dashboard-handler.GrafanaHandlerProps.property.grafanaPwSecret"></a>

```typescript
public readonly grafanaPwSecret: ISecret;
```

- *Type:* [`@aws-cdk/aws-secretsmanager.ISecret`](#@aws-cdk/aws-secretsmanager.ISecret)

The secret in SecretsManager containing your Grafana password.

If needed, specify an optional grafanaPwSecretKey to fetch a value for a specific JSON key in the Secret value.

---

##### `grafanaUrl`<sup>Required</sup> <a name="cdk-grafana-json-dashboard-handler.GrafanaHandlerProps.property.grafanaUrl"></a>

```typescript
public readonly grafanaUrl: string;
```

- *Type:* `string`

---

##### `localFilePath`<sup>Required</sup> <a name="cdk-grafana-json-dashboard-handler.GrafanaHandlerProps.property.localFilePath"></a>

```typescript
public readonly localFilePath: string;
```

- *Type:* `string`

The path to your local dashboard file.

Give it in so the Construct can calculate an MD5 hash of it. This is needed as otherwise CloudFormation would not know when to redeploy your dashboard to Grafana when it changes.

---

##### `objectKey`<sup>Required</sup> <a name="cdk-grafana-json-dashboard-handler.GrafanaHandlerProps.property.objectKey"></a>

```typescript
public readonly objectKey: string;
```

- *Type:* `string`

The object key in where you stored your dashboard file under.

---

##### `grafanaPwSecretKey`<sup>Optional</sup> <a name="cdk-grafana-json-dashboard-handler.GrafanaHandlerProps.property.grafanaPwSecretKey"></a>

```typescript
public readonly grafanaPwSecretKey: string;
```

- *Type:* `string`

The optional key to be looked up from your Grafana password secret in Secretsmanager.

---

##### `kmsKey`<sup>Optional</sup> <a name="cdk-grafana-json-dashboard-handler.GrafanaHandlerProps.property.kmsKey"></a>

```typescript
public readonly kmsKey: IKey;
```

- *Type:* [`@aws-cdk/aws-kms.IKey`](#@aws-cdk/aws-kms.IKey)

---

##### `timeout`<sup>Optional</sup> <a name="cdk-grafana-json-dashboard-handler.GrafanaHandlerProps.property.timeout"></a>

```typescript
public readonly timeout: Duration;
```

- *Type:* [`@aws-cdk/core.Duration`](#@aws-cdk/core.Duration)

---

##### `vpc`<sup>Optional</sup> <a name="cdk-grafana-json-dashboard-handler.GrafanaHandlerProps.property.vpc"></a>

```typescript
public readonly vpc: IVpc;
```

- *Type:* [`@aws-cdk/aws-ec2.IVpc`](#@aws-cdk/aws-ec2.IVpc)

---

##### `vpcSubnets`<sup>Optional</sup> <a name="cdk-grafana-json-dashboard-handler.GrafanaHandlerProps.property.vpcSubnets"></a>

```typescript
public readonly vpcSubnets: SubnetSelection;
```

- *Type:* [`@aws-cdk/aws-ec2.SubnetSelection`](#@aws-cdk/aws-ec2.SubnetSelection)

---



